==> supper_app-0.0.6.tar.gz: lib/src/services/web_service/dio_base.dart <==
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:get_it/get_it.dart';
import 'config/global_config.dart';

Future<Dio> setupDio() async {
  final options = BaseOptions(
    connectTimeout: 5000,
    receiveTimeout: 5000,
    responseType: ResponseType.json,
    validateStatus: (status) {
      return true;
    },
    baseUrl: GetIt.I<GlobalConfiguration>().getValue('base_url'),
  );
  final Dio dio = Dio();

  /// Adapt data (according to your own data structure, you can choose to add it)
  // dio.interceptors.add(TokenInterceptor());

  /// Print Log (production mode removal)
  // if (F.appFlavor != Flavor.prod) {
  dio.interceptors.add(CurlInterceptor());
  dio.interceptors.add(LogInterceptor(requestBody: true, responseBody: true));
  // }
  return dio;
}

class CurlInterceptor extends Interceptor {
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    try {
      final qp = options.queryParameters;
      final h = options.headers;
      final d = options.data;
      final curl = 'curl -X ${options.method} \'${options.baseUrl}${options.path}' +
          (qp.length != 0
              ? qp.keys.fold(
                  '',
                  (value, key) =>
                      '$value${value.length == 0 ? '?' : '&'}$key=${qp[key]}\'')
              : '\'') +
          h.keys.fold('', (value, key) => '$value -H \'$key: ${h[key]}\'') +
          (d.length != 0 ? ' --data-binary \'${json.encode(d)}\'' : '') +
          ' --insecure';
      print('server_curl: $curl');
    } catch (e) {
      print('CurlInterceptor error: $e');
    }

    super.onRequest(options, handler);
  }
}

==> supper_app-0.0.7.tar.gz: lib/src/services/web_service/dio_base.dart <==
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:get_it/get_it.dart';
import 'config/global_config.dart';

Future<Dio> setupDio() async {
  // final options = BaseOptions(
  //   connectTimeout: 5000,
  //   receiveTimeout: 5000,
  //   responseType: ResponseType.json,
  //   validateStatus: (status) {
  //     return true;
  //   },
  //   baseUrl: "iboard-dev.ssi.com.vn",
  // );
  final Dio dio = Dio();

  /// Adapt data (according to your own data structure, you can choose to add it)
  // dio.interceptors.add(TokenInterceptor());

  /// Print Log (production mode removal)
  // if (F.  != Flavor.prod) {
  dio.interceptors.add(CurlInterceptor());
  dio.interceptors.add(LogInterceptor(requestBody: true, responseBody: true));
  // }
  return dio;
}

class CurlInterceptor extends Interceptor {
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    try {
      final qp = options.queryParameters;
      final h = options.headers;
      final d = options.data;
      final curl = 'curl -X ${options.method} \'${options.baseUrl}${options.path}' +
          (qp.length != 0
              ? qp.keys.fold(
                  '',
                  (value, key) =>
                      '$value${value.length == 0 ? '?' : '&'}$key=${qp[key]}\'')
              : '\'') +
          h.keys.fold('', (value, key) => '$value -H \'$key: ${h[key]}\'') +
          (d.length != 0 ? ' --data-binary \'${json.encode(d)}\'' : '') +
          ' --insecure';
      print('server_curl: $curl');
    } catch (e) {
      print('CurlInterceptor error: $e');
    }

    super.onRequest(options, handler);
  }
}
